from setuptools import setup

setup(
    name="thehulk",
    version="0.1.1",
    description="smash!",
    url="https://github.com/wrecodde/thehulk",
    author="deji joseph",
    author_email="wrecodde@gmail.com",
    packages=["thehulk"],
    zip_safe=False )
